/***************************************************
 * atmospheric_pressure_2.pde
 * 
 * ネットから頂いた秋月の気圧センサの制御コードを使って、
 * これまた頂いたI2C制御用プログラムを改造して、
 * 計測値をLCDへ出力しています。
 * Read the Barometric Pressure and Temperature values from SCP1000 sensor
 * 
 * based on sample code from Arduino forum
 * http://www.arduino.cc/cgi-bin/yabb2/YaBB.pl?num=1236443720/8
 ************************************************/
#include <scp1000.h>

// 各種定義
#define SelectPin    10            // Specify slave select pin for SCP1000 device
// 外部変数（オブジェクト）宣言
SCP1000 scp1000(SelectPin);

void setup()
{
  Serial.begin(9600);             // Open serial connection to report values to host
  Serial.println("Starting up");
  (void)lcd_init();                // LCDを初期化。必要ないならコメントアウトして下さい。
  lcd_print("Air Observation!");
  delay(200);
  (void)scp1000.init();            // センサーを初期化
  delay(800);
}

void loop()
{
  int   air_pressure_I, temp_I, air_pressure_F, temp_F;

  // データ取得
  scp1000.readSensor();
  // LCDへの出力のためにデータを加工
  air_pressure_I  = (int)scp1000.BaroP;                          // 整数部を取得
  air_pressure_F  = (int)((long)(scp1000.BaroP * 100.0) % 100l); // 小数部を取得
  temp_I          = (int)scp1000.TempC;
  temp_F          = (int)((long)(scp1000.TempC * 100.0) % 100l);
  // LCDへデータを表示 必要ないならコメントアウトして下さい。
  lcd_print(air_pressure_I, 4, ' ', 1, 0);                       // 整数部を表示。4桁指定。余った分は半角スペースで埋める。1行目（0より数える）の0文字目に表示を指示。
  lcd_print(".");
  lcd_print(air_pressure_F, 2, '0');                             // 小数部を表示。2桁指定。余った分は'0'で埋める。
  lcd_print(",");
  lcd_print(temp_I, 2, ' ');
  lcd_print(".");
  lcd_print(temp_F, 2, '0');
  lcd_print("  ");
  // 取得データをシリアルへ送信
  Serial.print("Temprature (C),");
  Serial.print(scp1000.TempC);
  Serial.print(",Pressure (hPa),");
  Serial.println(scp1000.BaroP);
  delay(500);
}



